# Securities

A security is an investment instrument that you have purchased or sold. This can be a mutual fund, a stock, an ETF or even physical commodities such as gold or silver.

::: mkdocs-click
    :module: niveshpy.cli.security
    :command: cli
    :prog_name: niveshpy securities
    :depth: 1
    :list_subcommands: true

## Model Reference

::: niveshpy.models.security
